@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: streaming-commons
-version: 0.1.15.4
-id: streaming-commons-0.1.15.4-088f3eb5ae9c0f8f3bf543f124c940b6
-key: strea_FDgjqa6CVPZ2zy4YbsUfKW
+version: 0.1.15.5
+id: streaming-commons-0.1.15.5-b71913214a53247591329436a8fa2523
+key: strea_EmmPiWycOZRDBDTh9xaABj
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/streaming-commons
@@ -25,10 +25,10 @@ hidden-modules: Data.Text.Internal.Unsafe.Char
                 Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                 Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/streaming-commons-0.1.15.4
-hs-libraries: HSstreaming-commons-0.1.15.4-FDgjqa6CVPZ2zy4YbsUfKW
+import-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15.5
+library-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15.5
+data-dir: /usr/share/arm-linux-ghc-7.10.3/streaming-commons-0.1.15.5
+hs-libraries: HSstreaming-commons-0.1.15.5-EmmPiWycOZRDBDTh9xaABj
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
